# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - formdata (MoinForms)

    @copyright: 2013 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMoin.Page import Page
from MoinForms import loadFieldsFromString
from MoinSupport import *

Dependencies = ["pages"]

# Parser support.

class Parser:

    "Manipulate and display forms."

    Dependencies = Dependencies
    extensions = []

    def __init__(self, raw, request, **kw):

        """
        Initialise the parser with the given 'raw' data, 'request' and any
        keyword arguments that may have been supplied.
        """

        self.raw = raw
        self.request = request
        self.attrs = parseAttributes(kw.get("format_args", ""), False)

    def format(self, fmt, write=None):

        """
        Format the form data using the given formatter 'fmt'. If the 'write'
        parameter is specified, use it to write output; otherwise, write output
        using the request.

        Currently, this just writes a link to the form.
        """

        request = self.request
        page = request.page
        _ = fmt._

        number = page.page_name.rsplit("/", 1)[1]

        # Obtain the details of the form data.

        headers, data = loadFieldsFromString(self.raw)
        headers = dict(headers)

        form_pagename = headers.get("Form-Page")
        fragment = headers.get("Form-Fragment")

        write = write or request.write

        if form_pagename and number.isdigit():
            form_page = Page(request, form_pagename)
            query = {"fragment" : fragment, "load" : number, "action" : "MoinFormHandler"}
            write(linkToPage(request, form_page, _("Follow this link to view the form."), query, fragment))
        else:
            write(fmt.text(_("The form data does not specify the original form.")))

# vim: tabstop=4 expandtab shiftwidth=4
